@@ -6,6 +6,7 @@ diffnb <- function(x, y, verbose=TRUE) {
 	if (!inherits(x, "nb")) stop("not a neighbours list")
 	if (!inherits(y, "nb")) stop("not a neighbours list")
 	n <- length(x)
+	if (n < 1) stop("non-positive length of x")
 	if(n != length(y)) stop("lengths differ")
 	if (any(attr(x, "region.id") != attr(y, "region.id")))
 		warning("region.id differ; using ids of first list")
@@ -27,6 +28,7 @@ diffnb <- function(x, y, verbose=TRUE) {
 	class(res) <- "nb"
 	attr(res, "region.id") <- attr(x, "region.id")
 	attr(res, "call") <- match.call()
+	res <- sym.attr.nb(res)
 	invisible(res)
 }	
 	
